@@ -13,7 +13,7 @@ sub init {
   ok( $config, 'Got called with a config' );
   POE::Session->create(
      package_states => [
-        $package => [qw(_start sbox_smoke sbox_stop)],
+        $package => [qw(_start sbox_perl_info sbox_smoke sbox_stop)],
      ],
   );
 }
@@ -24,6 +24,14 @@ sub _start {
   return;
 }
 
+sub sbox_perl_info {
+  my ($version,$archname) = @_[ARG0,ARG1];
+  ok( $version, 'Got version info' );
+  ok( $archname, 'Got archname info' );
+  diag("v$version $archname\n");
+  return;
+}
+
 sub sbox_stop {
   my ($kernel,$session,@stats) = @_[KERNEL,SESSION,ARG0..$#_];
   is( scalar @stats, 8, 'Got the right number of stats entries' );
